pub struct Location<'a> {
filename: NonNull<str>,
line: u32,
col: u32,
_filename: PhantomData<&'a str>,
}Expand description
A struct containing information about the location of a panic.
This structure is created by PanicHookInfo::location() and PanicInfo::location().
Examples
use std::panic;
panic::set_hook(Box::new(|panic_info| {
if let Some(location) = panic_info.location() {
println!("panic occurred in file '{}' at line {}", location.file(), location.line());
} else {
println!("panic occurred but can't get location information...");
}
}));
panic!("Normal panic");Comparisons
Comparisons for equality and ordering are made in file, line, then column priority.
Files are compared as strings, not Path, which could be unexpected.
See Location::fileโs documentation for more discussion.
Fields
filename: NonNull<str>line: u32col: u32_filename: PhantomData<&'a str>Implementations
Sourceimpl<'a> Location<'a>
impl<'a> Location<'a>
1.46.0 (const: 1.79.0) ยท Sourcepub const fn caller() -> &'static Location<'static>
pub const fn caller() -> &'static Location<'static>
Returns the source location of the caller of this function. If that functionโs caller is annotated then its call location will be returned, and so on up the stack to the first call within a non-tracked function body.
Examples
use std::panic::Location;
/// Returns the [`Location`] at which it is called.
#[track_caller]
fn get_caller_location() -> &'static Location<'static> {
Location::caller()
}
/// Returns a [`Location`] from within this function's definition.
fn get_just_one_location() -> &'static Location<'static> {
get_caller_location()
}
let fixed_location = get_just_one_location();
assert_eq!(fixed_location.file(), file!());
assert_eq!(fixed_location.line(), 14);
assert_eq!(fixed_location.column(), 5);
// running the same untracked function in a different location gives us the same result
let second_fixed_location = get_just_one_location();
assert_eq!(fixed_location.file(), second_fixed_location.file());
assert_eq!(fixed_location.line(), second_fixed_location.line());
assert_eq!(fixed_location.column(), second_fixed_location.column());
let this_location = get_caller_location();
assert_eq!(this_location.file(), file!());
assert_eq!(this_location.line(), 28);
assert_eq!(this_location.column(), 21);
// running the tracked function in a different location produces a different value
let another_location = get_caller_location();
assert_eq!(this_location.file(), another_location.file());
assert_ne!(this_location.line(), another_location.line());
assert_ne!(this_location.column(), another_location.column());1.10.0 (const: 1.79.0) ยท Sourcepub const fn file(&self) -> &'a str
pub const fn file(&self) -> &'a str
Returns the name of the source file from which the panic originated.
&str, not &Path
The returned name refers to a source path on the compiling system, but it isnโt valid to
represent this directly as a &Path. The compiled code may run on a different system with
a different Path implementation than the system providing the contents and this library
does not currently have a different โhost pathโ type.
The most surprising behavior occurs when โthe sameโ file is reachable via multiple paths in
the module system (usually using the #[path = "..."] attribute or similar), which can
cause what appears to be identical code to return differing values from this function.
Cross-compilation
This value is not suitable for passing to Path::new or similar constructors when the host
platform and target platform differ.
Examples
use std::panic;
panic::set_hook(Box::new(|panic_info| {
if let Some(location) = panic_info.location() {
println!("panic occurred in file '{}'", location.file());
} else {
println!("panic occurred but can't get location information...");
}
}));
panic!("Normal panic");1.92.0 (const: 1.92.0) ยท Sourcepub const fn file_as_c_str(&self) -> &'a CStr
pub const fn file_as_c_str(&self) -> &'a CStr
Returns the name of the source file as a nul-terminated CStr.
This is useful for interop with APIs that expect C/C++ __FILE__ or
std::source_location::file_name, both of which return a nul-terminated const char*.
1.10.0 (const: 1.79.0) ยท Sourcepub const fn line(&self) -> u32
pub const fn line(&self) -> u32
Returns the line number from which the panic originated.
Examples
use std::panic;
panic::set_hook(Box::new(|panic_info| {
if let Some(location) = panic_info.location() {
println!("panic occurred at line {}", location.line());
} else {
println!("panic occurred but can't get location information...");
}
}));
panic!("Normal panic");1.25.0 (const: 1.79.0) ยท Sourcepub const fn column(&self) -> u32
pub const fn column(&self) -> u32
Returns the column from which the panic originated.
Examples
use std::panic;
panic::set_hook(Box::new(|panic_info| {
if let Some(location) = panic_info.location() {
println!("panic occurred at column {}", location.column());
} else {
println!("panic occurred but can't get location information...");
}
}));
panic!("Normal panic");Trait Implementations
1.10.0 ยท Sourceimpl Ord for Location<'_>
impl Ord for Location<'_>
1.21.0 ยท Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
1.10.0 ยท Sourceimpl PartialOrd for Location<'_>
impl PartialOrd for Location<'_>
impl<'a> Copy for Location<'a>
impl Eq for Location<'_>
impl Send for Location<'_>
impl Sync for Location<'_>